@@ -45,7 +45,7 @@ public class GNADataViewerConfigProfileReader {
 	 *
 	 */
 	public static final String SECONDARY_TYPE = "ApplicationProfile";
-	public static final String WORKSPACE_EXPLORER_APP_NAME = "GeoNa-Viewer-Profile";
+	public static final String GENERIC_RESOURCE_NAME = "Geoportal-DataViewer-Configs";
 	private static final String PATH_TO_ITEM_FIELDS_CONFIG = RESOURCE_PROFILE_BODY + "/item_fields_config";
 
 	private static Logger LOG = LoggerFactory.getLogger(GNADataViewerConfigProfileReader.class);
@@ -159,7 +159,7 @@ public class GNADataViewerConfigProfileReader {
 
 		} catch (Exception e) {
 			LOG.error("Error while trying to read the  " + SECONDARY_TYPE + " with SecondaryType "
-					+ WORKSPACE_EXPLORER_APP_NAME + " from scope " + scope, e);
+					+ GENERIC_RESOURCE_NAME + " from scope " + scope, e);
 			return null;
 		} finally {
 
